@@ -1,26 +1,23 @@
-# -*- coding: utf-8 -*-
-__version__ = "6.0.8"
+__version__ = "6.0.13"
+
+from zuper_commons.logs import ZLogger
+
 version = __version__
 
-import logging
-
-logging.basicConfig()
-logger = logging.getLogger(__name__)
-logger.setLevel(logging.DEBUG)
+logger = ZLogger(__name__)
 
 from .constants import *
 from .state import *
 from .storage import StorageFilesystem
 
-from .jobs import progress
 
-from .scripts.master import read_rc_files
 from .structures import Promise
 from .exceptions import *
 from .context import Context
-
+from .jobs import progress
 from . import plugins
 from .plugins.execution_stats import *
+from .scripts.master import read_rc_files
 
 # Default initialization
 set_compmake_status(CompmakeConstants.compmake_status_embedded)
