@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 __all__ = [
     "CompmakeConstants",
     "DefaultsToConfig",
@@ -37,6 +35,8 @@ class CompmakeConstants:
 
     extra_checks_job_states = False
 
+    tolerate_db_inconsistencies = True
+
     # Try to recover from anomalous situations
     try_recover = False
 
@@ -46,5 +46,5 @@ class CompmakeConstants:
 class DefaultsToConfig:
     """ Used to mean the param's default is from a config switch. """
 
-    def __init__(self, switch):
+    def __init__(self, switch: str):
         self.switch = switch
