@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import itertools
 import os
 import shutil
@@ -8,6 +6,7 @@ import traceback
 import warnings
 from abc import ABCMeta, abstractmethod
 from multiprocessing import TimeoutError
+from typing import Any, Collection, Dict, List, Set
 
 from compmake.constants import CompmakeConstants
 from compmake.jobs.storage import db_job_add_dynamic_children, db_job_add_parent
@@ -20,11 +19,12 @@ from .actions import mark_as_blocked
 from .priority import compute_priorities
 from .queries import direct_children, direct_parents
 from .uptodate import CacheQueryDB
+from .. import Context, StorageFilesystem
 from ..events import publish
 from ..exceptions import CompmakeBug, HostFailed, JobFailed, JobInterrupted
 from ..jobs import assert_job_exists, get_job_cache, job_cache_exists, job_exists, job_userobject_exists
 from ..jobs.actions_newprocess import result_dict_check
-from ..structures import Cache
+from ..structures import Cache, CMJobID, StateCode
 
 __all__ = [
     "Manager",
@@ -67,13 +67,13 @@ class ManagerLog(object):
         make_sure_dir_exists(log)
         self.f = open(log, "w")
 
-    def log(self, s, **kwargs):
+    def log(self, s: str, **kwargs: Any):
 
         for k in sorted(kwargs):
             v = kwargs[k]
             if isinstance(v, set):
                 v = sorted(v)
-            s += "\n - %15s: %s" % (k, v)
+            s += f"\n - {k:>15}: {v}"
         self.f.write(s)
         # print(s)
         self.f.write("\n")
@@ -82,9 +82,20 @@ class ManagerLog(object):
 
 
 class Manager(ManagerLog):
+    cq: CacheQueryDB
+    context: Context
+    db: StorageFilesystem
+    targets: Set[CMJobID]
+    """ top level"""
+    all_targets: Set[CMJobID]
+    deleted: Set[CMJobID]
+    todo: Set[CMJobID]
+    ready_todo: Set[CMJobID]
+    processing: Set[CMJobID]
+    processing2result: Dict[CMJobID, Any]
 
     # noinspection PyUnusedLocal
-    def __init__(self, context, cq, recurse: bool = False):
+    def __init__(self, context, cq: CacheQueryDB, recurse: bool = False):
         self.context = context
         # self.cq = cq
         self.db = context.get_compmake_db()
@@ -135,18 +146,18 @@ class Manager(ManagerLog):
         """ Called after successful processing (before cleanup) """
 
     @abstractmethod
-    def can_accept_job(self, reasons):
+    def can_accept_job(self, reasons: Dict[str, str]) -> bool:
         """ Return true if a new job can be accepted right away"""
 
     @abstractmethod
-    def instance_job(self, job_id):
+    def instance_job(self, job_id: CMJobID):
         """ Instances a job. """
 
     def cleanup(self):
         """ free up any resource, called wheter succesfull or not."""
         pass
 
-    def next_job(self) -> str:
+    def next_job(self) -> CMJobID:
         """
             Returns one job from the ready_todo list
             Uses self.priorities to decide which job to use.
@@ -159,14 +170,14 @@ class Manager(ManagerLog):
         # print('choosing %s job %r' % (self.priorities[best], best))
         return best
 
-    def add_targets(self, targets):
+    def add_targets(self, targets: Collection[CMJobID]):
         self.log("add_targets()", targets=targets)
         self.check_invariants()
         for t in targets:
             assert_job_exists(t, self.db)
 
             if t in self.processing:
-                msg = "Adding a job already in processing: %r" % t
+                msg = f"Adding a job already in processing: {t!r}"
                 raise CompmakeBug(msg)
 
             if t in self.targets:
@@ -197,7 +208,7 @@ class Manager(ManagerLog):
             not_ready=not_ready,
         )
 
-        self.log("targets_todo_plus_deps: %s" % sorted(targets_todo_plus_deps))
+        self.log(f"targets_todo_plus_deps: {sorted(targets_todo_plus_deps)}")
 
         # print(' targets_todo_plus_deps: %s ' % targets_todo_plus_deps)
         # print('           targets_done: %s ' % targets_done)
@@ -282,7 +293,7 @@ class Manager(ManagerLog):
         return reasons
 
     def _raise_bug(self, func, job_id):
-        msg = "%s: Assumptions violated with job %r." % (func, job_id)
+        msg = f"{func}: Assumptions violated with job {job_id!r}."
         # msg += '\n' + self._get_situation_string()
 
         sets = [
@@ -298,17 +309,17 @@ class Manager(ManagerLog):
 
         for name, cont in sets:
             contained = job_id in cont
-            msg += "\n in %15s? %s" % (name, contained)
+            msg += f"\n in {name:>15}? {contained}"
 
         raise CompmakeBug(msg)
 
-    def start_job(self, job_id):
+    def start_job(self, job_id: CMJobID):
         self.log("start_job", job_id=job_id)
         self.check_invariants()
         if job_id not in self.ready_todo:
             self._raise_bug("start_job", job_id)
 
-        publish(self.context, "manager-job-starting", job_id=job_id)
+        publish(self.context, "manager-job-processing", job_id=job_id)
         self.ready_todo.remove(job_id)
         self.processing.add(job_id)
         self.processing2result[job_id] = self.instance_job(job_id)
@@ -319,7 +330,7 @@ class Manager(ManagerLog):
 
         self.check_invariants()
 
-    def check_job_finished(self, job_id, assume_ready=False):
+    def check_job_finished(self, job_id: CMJobID, assume_ready: bool = False):
         """
             Checks that the job finished succesfully or unsuccesfully.
 
@@ -396,9 +407,9 @@ class Manager(ManagerLog):
             print(traceback.format_exc())
             raise JobInterrupted("Keyboard interrupt")
 
-    def job_is_deleted(self, job_id):
+    def job_is_deleted(self, job_id: CMJobID):
         if job_exists(job_id, self.db):
-            msg = "Job %r declared deleted still exists" % job_id
+            msg = f"Job {job_id!r} declared deleted still exists"
             raise CompmakeBug(msg)
         if job_id in self.all_targets:
             if job_id in self.todo:
@@ -458,11 +469,11 @@ class Manager(ManagerLog):
                     # print('was also in targets')
                     # Remove it from the "ready_todo_list"
                     if parent in self.processing2result:
-                        msg = "parent %s of %s is already processing?" % (job_id, parent)
+                        msg = f"parent {job_id} of {parent} is already processing?"
                         raise CompmakeBug(msg)
 
                     if parent in self.done:
-                        msg = " parent %s of %s is already done?" % (job_id, parent)
+                        msg = f" parent {job_id} of {parent} is already done?"
                         warnings.warn("not sure of this...")
                         # raise CompmakeBug(msg)#
 
@@ -515,7 +526,7 @@ class Manager(ManagerLog):
 
         self.check_invariants()
 
-    def job_failed(self, job_id, deleted_jobs):
+    def job_failed(self, job_id: CMJobID, deleted_jobs):
         """ The specified job has failed. Update the structures,
             mark any parent as failed as well. """
         self.log("job_failed", job_id=job_id, deleted_jobs=deleted_jobs)
@@ -541,19 +552,22 @@ class Manager(ManagerLog):
 
         parents_todo = set(self.todo & parent_jobs)
         for p in parents_todo:
-            mark_as_blocked(p, job_id, db=self.db)
-            self.todo.remove(p)
-            self.blocked.add(p)
+            if p not in self.blocked:
+                publish(self.context, "manager-job-blocked", job_id=p, blocking_job_id=job_id)
+
+                mark_as_blocked(p, dependency=job_id, db=self.db)
+                self.todo.remove(p)
+                self.blocked.add(p)
 
         self.publish_progress()
         self.check_invariants()
 
-    def job_succeeded(self, job_id):
+    def job_succeeded(self, job_id: CMJobID):
         """ Mark the specified job as succeeded. Update the structures,
             mark any parents which are ready as ready_todo. """
         self.log("job_succeeded", job_id=job_id)
         self.check_invariants()
-        publish(self.context, "manager-job-succeeded", job_id=job_id)
+        publish(self.context, "manager-job-done", job_id=job_id)
         assert job_id in self.processing
 
         self.processing.remove(job_id)
@@ -571,7 +585,7 @@ class Manager(ManagerLog):
         for opportunity in parents_todo:
             # print('parent %r in todo' % (opportunity))
             if opportunity in self.processing:
-                msg = "Parent %r of %r already processing" % (opportunity, job_id)
+                msg = f"Parent {opportunity!r} of {job_id!r} already processing"
                 if CompmakeConstants.try_recover:
                     print(msg)
                     continue
@@ -604,6 +618,7 @@ class Manager(ManagerLog):
                 # print('parent %r is now ready' % (opportunity))
                 self.log("parent is ready", opportunity=opportunity)
                 self.todo.remove(opportunity)
+                publish(self.context, "manager-job-ready", job_id=opportunity)
                 self.ready_todo.add(opportunity)
 
         self.check_invariants()
@@ -674,7 +689,7 @@ class Manager(ManagerLog):
         try:
             i = 0
             while self.todo or self.ready_todo or self.processing:
-                self.log(indent(self._get_situation_string(), "%s: " % i))
+                self.log(indent(self._get_situation_string(), f"{i}: "))
                 i += 1
                 self.check_invariants()
                 # either something ready to do, or something doing
@@ -731,12 +746,13 @@ class Manager(ManagerLog):
             return True
 
         except JobInterrupted as e:
-            from ..ui import error
 
-            error("Received JobInterrupted: %s" % e)
+            from compmake.ui.visualization import ui_error
+
+            ui_error(self.context, f"Received JobInterrupted: {e}")
             raise
         except KeyboardInterrupt:
-            raise KeyboardInterrupt("Manager interrupted.")
+            raise KeyboardInterrupt("Manager interrupted.") from None
         finally:
             self.cleanup()
 
@@ -770,16 +786,16 @@ class Manager(ManagerLog):
         s = ""
         for t in sorted(lists):
             jobs = lists[t]
-            s += "- %12s: %d\n" % (t, len(jobs))
+            s += f"- {t:>12}: {len(jobs)}\n"
 
         # if False:
         s += "\n In more details:"
         for t in sorted(lists):
             jobs = lists[t]
             if not jobs:
-                s += "\n- %12s: -" % (t)
+                s += f"\n- {t:>12}: -"
             elif len(jobs) < 20:
-                s += "\n- %12s: %d %s" % (t, len(jobs), sorted(jobs))
+                s += f"\n- {t:>12}: {len(jobs)} {sorted(jobs)}"
 
         return s
 
@@ -800,8 +816,8 @@ class Manager(ManagerLog):
         def empty_intersection(a, b):
             inter = lists[a] & lists[b]
             if inter:
-                msg = "There should be empty intersection in %r and %r" % (a, b)
-                msg += " but found %s" % inter
+                msg = f"There should be empty intersection in {a!r} and {b!r}"
+                msg += f" but found {inter}"
 
                 st = self._get_situation_string()
                 if len(st) < 500:
@@ -812,15 +828,15 @@ class Manager(ManagerLog):
         def partition(sets, result):
             S = set()
             for s in sets:
-                S = S | lists[s]
+                S |= lists[s]
 
             if S != lists[result]:
                 msg = "These two sets should be the same:\n"
                 msg += " %s = %s\n" % (" + ".join(list(sets)), result)
-                msg += " first = %s\n" % S
-                msg += " second = %s\n" % lists[result]
-                msg += " first-second = %s\n" % (S - lists[result])
-                msg += " second-first = %s\n" % (lists[result] - S)
+                msg += f" first = {S}\n"
+                msg += f" second = {lists[result]}\n"
+                msg += f" first-second = {S - lists[result]}\n"
+                msg += f" second-first = {lists[result] - S}\n"
 
                 st = self._get_situation_string()
                 if len(st) < 500:
@@ -854,27 +870,25 @@ class Manager(ManagerLog):
                     raise CompmakeBug("job %r in blocked does not exist" % job_id)
 
 
-def check_job_cache_state(job_id, states, db):
+def check_job_cache_state(job_id: CMJobID, states: List[StateCode], db):
     """ Raises CompmakeBug if the job is not marked as done. """
     if not CompmakeConstants.extra_checks_job_states:  # XXX: extra check
         return
 
     if not job_cache_exists(job_id, db):
-        msg = "The job %r was reported as done/failed but no record of " "it was found." % job_id
+        msg = f"The job {job_id!r} was reported as done/failed but no record of it was found."
         raise CompmakeBug(msg)
     else:
         cache = get_job_cache(job_id, db)
         if not cache.state in states:
-            msg = "Wrong state for %r: %s instead of %r " % (
-                job_id,
-                Cache.state2desc[cache.state],
-                [Cache.state2desc[s] for s in states],
-            )
+            possible = [Cache.state2desc[s] for s in states]
+            found = Cache.state2desc[cache.state]
+            msg = f"Wrong state for {job_id!r}: {found} instead of {possible!r} "
             raise CompmakeBug(msg)
 
         if cache.state == Cache.DONE:
             if not job_userobject_exists(job_id, db):
-                msg = "Job %r marked as DONE but no userobject exists" % job_id
+                msg = f"Job {job_id!r} marked as DONE but no userobject exists"
                 raise CompmakeBug(msg)
 
 
@@ -926,18 +940,18 @@ def check_job_cache_state(job_id, states, db):
 def check_job_cache_says_failed(job_id, db, e):
     """ Raises CompmakeBug if the job is not marked as failed. """
     if not job_cache_exists(job_id, db):
-        msg = "The job %r was reported as failed but no record of " "it was found." % job_id
-        msg += "\n" + "JobFailed exception:"
-        msg += "\n" + indent(str(e), "| ")
-        raise CompmakeBug(msg)
+        msg = f"The job {job_id!r} was reported as failed but no record of it was found."
+        # msg += "\n" + "JobFailed exception:"
+        # msg += "\n" + indent(str(e), "| ")
+        raise CompmakeBug(msg, e=str(e))
     else:
         cache = get_job_cache(job_id, db)
         if not cache.state == Cache.FAILED:
-            msg = "The job %r was reported as failed but it was " "not marked as such in the DB." % job_id
-            msg += "\n seen state: %s " % Cache.state2desc[cache.state]
-            msg += "\n" + "JobFailed exception:"
-            msg += "\n" + indent(str(e), "| ")
-            raise CompmakeBug(msg)
+            msg = f"The job {job_id!r} was reported as failed but it was not marked as such in the DB."
+            msg += f"\n seen state: {Cache.state2desc[cache.state]} "
+            # msg += "\n" + "JobFailed exception:"
+            # msg += "\n" + indent(str(e), "| ")
+            raise CompmakeBug(msg, e=str(e))
 
 
 #
