@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
-
 from compmake.jobs.priority import compute_priorities
 from compmake.ui.helpers import COMMANDS_ADVANCED, ui_command
 
 
 @ui_command(section=COMMANDS_ADVANCED)
-def debug_priority(non_empty_job_list, context, cq):  # @UnusedVariable
+def debug_priority(non_empty_job_list, context, cq):
     """ Shows the priority of jobs. """
     jobs = list(non_empty_job_list)
     priorities = compute_priorities(all_targets=jobs, cq=cq)
