@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """ This plugin dumps all events received. """
 import sys
 
@@ -12,7 +10,7 @@ stream = sys.stderr
 other_stream = sys.stdout
 
 
-def print_event(context, event):  # @UnusedVariable
+def print_event(context, event):
     other_stream.flush()
 
     # age = time.time() - event.timestamp
@@ -30,7 +28,7 @@ def print_event(context, event):  # @UnusedVariable
         s = s[: MAX_LEN - len(suff)] + suff
     #        s = s[:MAX_LEN]
 
-    msg = "%s: %s" % (event.name, s)
+    msg = f"{event.name}: {s}"
     msg = compmake_colored(pad_to_screen(msg), "yellow")
     stream.write(msg)
     stream.write("\n")
